import React, { useState } from "react";
import { Box,  Button, Typography, Stack, InputLabel, OutlinedInput, InputAdornment, IconButton, FormControlLabel, Checkbox } from "@mui/material";
import Grid from "@mui/material/Grid2";
import { interviewImg } from "../assets/index";
import RemoveRedEyeOutlinedIcon from '@mui/icons-material/RemoveRedEyeOutlined';
import VisibilityOffOutlinedIcon from '@mui/icons-material/VisibilityOffOutlined';
import { Formik } from "formik";
import { Link } from "react-router-dom";

const LoginPage = () => {
  // States
  const [showPassword, setShowPassword] = useState(false);
  const [checked, setChecked] = useState(false);


  // Functions
  const handleClickShowPassword = () => {
    const input = document.getElementById('password-login');
    const cursorPosition = input.selectionStart;
    setShowPassword((prev) => !prev);
    setTimeout(() => {
      input.focus();
      input.setSelectionRange(cursorPosition, cursorPosition);
    }, 0);
  };

  return (
    <Grid container sx={{ minHeight: "100vh" }} >
      {/* Left Side (Image Section) */}
      <Grid
        size={{ xs: 0, sm: 0, md: 7 }}
        sx={{
          backgroundImage: `url(${interviewImg})`,
          backgroundRepeat: "no-repeat",
          backgroundSize: "cover",
          backgroundPosition: "center",
        }}
      ></Grid>

      {/* Right Side (Login Form Section) */}
      <Grid
        item
        size={{ xs: 12, sm: 12, md: 5 }}
        sx={{
          display: "flex",
          alignItems: "center",
          justifyContent: "center",
          padding: 3,
        }}
      >
        <Box
          sx={{
            width: "100%",
            maxWidth: 500,
            padding: 3,
            boxShadow: 3,
            borderRadius: 2,
            backgroundColor: "white",
          }}
        >
          <Typography variant="h4" gutterBottom align="center">
            Welcome to <b style={{ color: 'theme.palette.primary' }}>Skillov.ai</b>
          </Typography>
          <Formik
            initialValues={{ email: '', password: '' }}
          // validate={}
          // onSubmit={}
          >
            {
              ({ values, errors, touched, handleChange, handleBlur, handleSubmit, isSubmitting }) => (
                <form onSubmit={handleSubmit}>

                  <Stack spacing={1} gutterBottom>
                    <InputLabel htmlFor="email-login" required sx={{ fontWeight:600}}>
                      Email
                    </InputLabel>
                    <OutlinedInput
                      id="email-login"
                      type="email"
                      value={values?.email}
                      name="email"
                      onBlur={handleBlur}
                      onChange={handleChange}
                      placeholder="Enter Email"
                      fullWidth
                      error={Boolean(touched?.email && errors?.email)}
                    />
                    {touched.email && errors.email && (
                      <FormHelperText error sx={{ ml: 0 }}>
                        {errors.email}
                      </FormHelperText>
                    )}
                  </Stack>

                  <Stack spacing={1} sx={{mt:2}}>
                    <InputLabel htmlFor="password-login" required sx={{ fontWeight:600}}>
                      Create Password
                    </InputLabel>
                    <OutlinedInput
                      fullWidth
                      error={Boolean(touched.password && errors.password)}
                      id="password-login"
                      type={showPassword ? 'text' : 'password'}
                      value={values.password}
                      name="password"
                      onBlur={handleBlur}
                      onChange={handleChange}
                      autoComplete="new-password"
                      endAdornment={
                        <InputAdornment position="end">
                          <IconButton
                            aria-label="toggle password visibility"
                            onClick={handleClickShowPassword}
                            edge="end"
                            color="secondary"
                          >
                            {showPassword ? <RemoveRedEyeOutlinedIcon /> : <VisibilityOffOutlinedIcon />}
                          </IconButton>
                        </InputAdornment>
                      }
                      placeholder="Enter password"
                    />
                    {touched?.password && errors?.password && (
                      <FormHelperText error id="standard-weight-helper-text-password-login">
                        {errors.password}
                      </FormHelperText>
                    )}
                  </Stack>


                  <Box  >
                    <Stack direction={"row"} sx={{ justifyContent: 'space-between', mt:1 }} >
                      <FormControlLabel
                        control={
                          <Checkbox
                            checked={checked}
                            onChange={(event) => setChecked(event.target.checked)}
                            name="checked"
                            color="primary"
                            size="small"
                          />
                        }
                        label={'Remember me'}
                      />
                      <Button sx={{ px: 0 }} onClick={() => setForgotPassModal(true)}>Forgot password?</Button>
                    </Stack>

                  </Box>

                  <Button variant="contained" color="primary" fullWidth sx={{ mt: 2 }} type="submit" disabled={isSubmitting}>
                    Login
                  </Button>

                </form>
              )
            }

          </Formik>
          <Typography variant="body2" align="center" sx={{ mt: 2 }}>
            Don't have an account? <Link to='job-description' style={{ textDecoration: 'none', color: 'theme.palette.primary' }}>Create an account</Link>
          </Typography>

        </Box>
      </Grid>
    </Grid>
  );
};

export default LoginPage;